package com.jkcredit.invoice.config;

import com.jkcredit.invoice.util.LogFileName;
import com.jkcredit.invoice.util.LoggerUtil;
import com.jkcredit.invoice.util.RespR;
import org.slf4j.Logger;
import org.springframework.http.HttpStatus;
import org.springframework.validation.BindException;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @description:
 * @author: sunzhaoning
 * @create: 2019-05-29 13:43
 * @version: V1.0
 **/
@RestControllerAdvice
public class GlobalExceptionHandler {
    Logger MIX_LOG = LoggerUtil.logger(LogFileName.MIX_LOG);

    /**
     * 全局异常
     * @param e
     * @return RespR
     */
    @ExceptionHandler(Exception.class)
    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    public RespR exception(Exception e) {
        MIX_LOG.error("全局异常信息，异常信息为：{}", e.getMessage(), e);
        return new RespR<>(e);
    }

    /**
     * validation Exception
     * @param exception
     * @return RespR
     */
    @ExceptionHandler({MethodArgumentNotValidException.class, BindException.class})
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public RespR bodyValidExceptionHandler(MethodArgumentNotValidException exception) {
        List<FieldError> fieldErrors = exception.getBindingResult().getFieldErrors();
        RespR result = new RespR();
        result.setMsg(fieldErrors.get(0).getDefaultMessage());
        MIX_LOG.warn(fieldErrors.get(0).getDefaultMessage());
        return result;
    }

}
